@@ -1,4 +1,22 @@
-import atexit
+# This file is part of fedmsg.
+# Copyright (C) 2012 Red Hat, Inc.
+#
+# fedmsg is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
+#
+# fedmsg is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public
+# License along with fedmsg; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+#
+# Authors:  Ralph Bean <rbean@redhat.com>
+#
 import inspect
 import socket
 import time
@@ -41,7 +59,7 @@ class FedMsgContext(object):
         if not config.get("name", None):
             config["name"] = self.guess_calling_module() + '.' + self.hostname
 
-            if any(map(config["name"].startswith, ['__main__', 'fedmsg'])):
+            if any(map(config["name"].startswith, ['fedmsg'])):
                 config["name"] = None
 
         # Find my message-signing cert if I need one.
@@ -56,7 +74,11 @@ class FedMsgContext(object):
             self.c['certname'] = self.c['certnames'][cert_index]
 
         # Actually set up our publisher
-        if config.get("name", None) and config.get("endpoints", None):
+        if (
+            config.get("name", None) and
+            config.get("endpoints", None) and
+            config['endpoints'].get(config['name'])
+        ):
             self.publisher = self.context.socket(zmq.PUB)
 
             if config['high_water_mark']:
@@ -96,13 +118,14 @@ class FedMsgContext(object):
         else:
             warnings.warn("fedmsg is not configured to send any messages")
 
-        atexit.register(self.destroy)
-
         # Sleep just to make sure that the socket gets set up before anyone
         # tries anything.  This is a documented zmq 'feature'.
         time.sleep(config['post_init_sleep'])
 
     def destroy(self):
+        self.__del__()
+
+    def __del__(self):
         """ Destructor """
         if getattr(self, 'publisher', None):
             self.publisher.close()
