@@ -17,12 +17,11 @@ import moksha
 import unittest
 
 import os
+import socket
 
 from time import sleep, time
 from uuid import uuid4
 
-from unittest import TestCase
-
 from moksha.tests.test_hub import simulate_reactor
 from moksha.hub.hub import MokshaHub
 from moksha.hub import CentralMokshaHub
@@ -58,8 +57,9 @@ def load_config(name='fedmsg-test-config.py'):
     config['zmq_subscribe_endpoints'] = ','.join(
         ','.join(bunch) for bunch in config['endpoints'].values()
     )
+    hub_name = "twisted.%s" % socket.gethostname()
     config['zmq_publish_endpoints'] = ','.join(
-        config['endpoints'].values()[1]
+        config['endpoints'][hub_name]
     )
     return config
 
@@ -72,7 +72,7 @@ def test_init_missing_endpoint():
     context = FedMsgContext(**config)
 
 
-class TestHub(TestCase):
+class TestHub(unittest.TestCase):
 
     def setUp(self):
         config = load_config()
@@ -229,3 +229,7 @@ class TestHub(TestCase):
 
         # Verify that we received no message.
         eq_(len(messages_received), 0)
+
+
+if __name__ == '__main__':
+    unittest.main()
